package com.sf.system.deployment.service;

import com.sf.system.deployment.domain.DeploymentWhitelistList;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;

/**
 * 白名单成员列Service接口
 * 
 * @author ztzh
 * @date 2024-05-06
 */
public interface IDeploymentWhitelistListService 
{
    /**
     * 查询白名单成员列
     * 
     * @param id 白名单成员列主键
     * @return 白名单成员列
     */
    public DeploymentWhitelistList selectDeploymentWhitelistListById(Long id);

    /**
     * 查询白名单成员列列表
     * 
     * @param deploymentWhitelistList 白名单成员列
     * @return 白名单成员列集合
     */
    public List<DeploymentWhitelistList> selectDeploymentWhitelistListList(DeploymentWhitelistList deploymentWhitelistList);

    /**
     * 新增白名单成员列
     *
     * @param deploymentWhitelistList 白名单成员列
     * @param username
     * @return 结果
     */
    public int insertDeploymentWhitelistList(DeploymentWhitelistList deploymentWhitelistList, String username);

    /**
     * 修改白名单成员列
     * 
     * @param deploymentWhitelistList 白名单成员列
     * @return 结果
     */
    public int updateDeploymentWhitelistList(DeploymentWhitelistList deploymentWhitelistList);

    /**
     * 批量删除白名单成员列
     * 
     * @param ids 需要删除的白名单成员列主键集合
     * @return 结果
     */
    public int deleteDeploymentWhitelistListByIds(Long[] ids);

    /**
     * 删除白名单成员列信息
     * 
     * @param id 白名单成员列主键
     * @return 结果
     */
    public int deleteDeploymentWhitelistListById(Long id);

    public int batchImport(MultipartFile file, Long whitelistId, String username) throws IOException;
}
